@@ -9,6 +9,8 @@ from pkg_resources import parse_version
 from io import StringIO
 import logging as pyLog
 import six
+import sys
+import threading
 
 # workaround for python2/3 string handling {{{
 try:
@@ -173,13 +175,23 @@ class Cdo(object):
         self.logger = setupLogging(self.logFile)  # }}}
 
     # handling different exits from interactive sessions {{{
-    #   remove tempfiles from those sessions
-    signal.signal(signal.SIGINT, self.__catch__)
-    signal.signal(signal.SIGTERM, self.__catch__)
-    signal.signal(signal.SIGSEGV, self.__catch__)
-    signal.siginterrupt(signal.SIGINT, False)
-    signal.siginterrupt(signal.SIGTERM, False)
-    signal.siginterrupt(signal.SIGSEGV, False)
+    # python3 has threading.main_thread(), but python2 doesn't
+    if (2 == sys.version_info[0]): # check python major version
+      signal.signal(signal.SIGINT,  self.__catch__)
+      signal.signal(signal.SIGTERM, self.__catch__)
+      signal.signal(signal.SIGSEGV, self.__catch__)
+      signal.siginterrupt(signal.SIGINT,  False)
+      signal.siginterrupt(signal.SIGTERM, False)
+      signal.siginterrupt(signal.SIGSEGV, False)
+    else:
+      #   remove tempfiles from those sessions
+      if threading.current_thread() is threading.main_thread():
+        signal.signal(signal.SIGINT,  self.__catch__)
+        signal.signal(signal.SIGTERM, self.__catch__)
+        signal.signal(signal.SIGSEGV, self.__catch__)
+        signal.siginterrupt(signal.SIGINT,  False)
+        signal.siginterrupt(signal.SIGTERM, False)
+        signal.siginterrupt(signal.SIGSEGV, False)
     # other left-overs can only be handled afterwards
     # might be good to use the tempdir keyword to ease this, but deletion can
     # be triggered using cleanTempDir() }}}
